@@ -9,8 +9,8 @@
     :copyright: (c) 2010 by Armin Ronacher.
     :license: GPLv3, see LICENSE for more details.
 """
-import flask.ext.babel
-from flask.ext.babel import Babel  # noqa
+import flaskext.babel
+from flaskext.babel import Babel
 from babel import support, Locale
 from pytz import timezone
 from nereid.globals import _request_ctx_stack
@@ -33,7 +33,7 @@ def get_translations():
     return translations
 
 
-flask.ext.babel.get_translations = get_translations
+flaskext.babel.get_translations = get_translations
 
 
 def get_locale():
@@ -61,7 +61,7 @@ def get_locale():
         ctx.babel_locale = locale
     return locale
 
-flask.ext.babel.get_locale = get_locale
+flaskext.babel.get_locale = get_locale
 
 
 def get_timezone():
@@ -89,4 +89,4 @@ def get_timezone():
         ctx.babel_tzinfo = tzinfo
     return tzinfo
 
-flask.ext.babel.get_timezone = get_timezone
+flaskext.babel.get_timezone = get_timezone
